summaryrefslogtreecommitdiffstats
path: root/core/java/android
diff options
context:
space:
mode:
authorBjorn Bringert <bringert@android.com>2010-01-13 21:09:20 +0000
committerBjorn Bringert <bringert@android.com>2010-01-13 21:09:20 +0000
commita94e7afb28c6bd9af6f2b0142a577086399066b2 (patch)
treeb888cbfdb1a95e10d09f7bb500754ef91d0cb7a0 /core/java/android
parent4a5bff9e272247b0ad9f8125f18c3f0043b5f9fd (diff)
downloadframeworks_base-a94e7afb28c6bd9af6f2b0142a577086399066b2.zip
frameworks_base-a94e7afb28c6bd9af6f2b0142a577086399066b2.tar.gz
frameworks_base-a94e7afb28c6bd9af6f2b0142a577086399066b2.tar.bz2
Remove Intent.ACTION_GLOBAL_SEARCH
I added Intent.ACTION_GLOBAL_SEARCH a little while ago, since I thought we needed it to be different from the old SearchManager.INTENT_ACTION_GLOBAL_SEARCH. Since GlobalSearch is no longer built, reusing SearchManager.INTENT_ACTION_GLOBAL_SEARCH should be fine. Change-Id: If3a11a77a8e1d9940cf2b20817a60888cdd9d69f
Diffstat (limited to 'core/java/android')
-rw-r--r--core/java/android/app/SearchManager.java8
-rw-r--r--core/java/android/content/Intent.java10
2 files changed, 4 insertions, 14 deletions
diff --git a/core/java/android/content/Intent.java b/core/java/android/content/Intent.java
index bf37b62..bbd359b 100644
--- a/core/java/android/content/Intent.java
+++ b/core/java/android/content/Intent.java
@@ -1102,16 +1102,6 @@ public class Intent implements Parcelable, Cloneable {
public static final String ACTION_SEARCH_LONG_PRESS = "android.intent.action.SEARCH_LONG_PRESS";
/**
- * Activity Action: Start the global search activity.
- * <p>Input: Nothing.
- * <p>Output: Nothing.
- *
- * @hide Pending API council approval
- */
- @SdkConstant(SdkConstantType.ACTIVITY_INTENT_ACTION)
- public static final String ACTION_GLOBAL_SEARCH = "android.intent.action.GLOBAL_SEARCH";
-
- /**
* Activity Action: The user pressed the "Report" button in the crash/ANR dialog.
* This intent is delivered to the package which installed the application, usually
* the Market.
diff --git a/core/java/android/app/SearchManager.java b/core/java/android/app/SearchManager.java
index a75e8dc..9112be4 100644
--- a/core/java/android/app/SearchManager.java
+++ b/core/java/android/app/SearchManager.java
@@ -1332,7 +1332,7 @@ public class SearchManager
public final static String EXTRA_DATA_KEY = "intent_extra_data_key";
/**
* String extra data key for {@link Intent#ACTION_GLOBAL_SEARCH} intents. Contains the initial
* query to show in the global search activity.
*
* @hide Pending API council approval
@@ -1340,7 +1340,7 @@ public class SearchManager
public final static String INITIAL_QUERY = "initial_query";
/**
* Boolean extra data key for {@link Intent#ACTION_GLOBAL_SEARCH} intents. If {@code true},
* the initial query should be selected.
*
* @hide Pending API council approval
@@ -1816,7 +1816,7 @@ public class SearchManager
Log.w(TAG, "No global search activity found.");
return;
}
- Intent intent = new Intent(Intent.ACTION_GLOBAL_SEARCH);
+ Intent intent = new Intent(INTENT_ACTION_GLOBAL_SEARCH);
intent.setComponent(globalSearchActivity);
// TODO: Always pass name of calling package as an extra?
if (appSearchData != null) {
@@ -1847,7 +1847,7 @@ public class SearchManager
* we have settled on the right mechanism for finding the global search activity.
*/
private ComponentName getGlobalSearchActivity() {
- Intent intent = new Intent(Intent.ACTION_GLOBAL_SEARCH);
+ Intent intent = new Intent(INTENT_ACTION_GLOBAL_SEARCH);
PackageManager pm = mContext.getPackageManager();
List<ResolveInfo> activities =
pm.queryIntentActivities(intent, PackageManager.MATCH_DEFAULT_ONLY);
@@ -1332,7 +1332,7 @@ public class SearchManager
public final static String EXTRA_DATA_KEY = "intent_extra_data_key";
/**
- * String extra data key for {@link Intent#ACTION_GLOBAL_SEARCH} intents. Contains the initial
+ * String extra data key for {@link #INTENT_ACTION_GLOBAL_SEARCH} intents. Contains the initial
* query to show in the global search activity.
*
@@ -1340,7 +1340,7 @@ public class SearchManager
public final static String INITIAL_QUERY = "initial_query";
/**
- * Boolean extra data key for {@link Intent#ACTION_GLOBAL_SEARCH} intents. If {@code true},
+ * Boolean extra data key for {@link Intent#INTENT_ACTION_GLOBAL_SEARCH} intents. If {@code true},
* the initial query should be selected.
*